@@ -1,10 +1,10 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco.h,v 1.526 2014/11/26 05:18:52 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco.h,v 1.538 2015/02/07 04:39:39 zender Exp $ */
 
 /* Purpose: netCDF Operator (NCO) definitions */
 
-/* Copyright (C) 1995--2014 Charlie Zender
+/* Copyright (C) 1995--2015 Charlie Zender
    This file is part of NCO, the netCDF Operators. NCO is free software.
-   You can redistribute and/or modify NCO under the terms of the 
+   You may redistribute and/or modify NCO under the terms of the 
    GNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file */
 
 /* Usage:
@@ -159,7 +159,7 @@ extern "C" {
   /* netCDF provides no guidance on maximum nesting of groups */
 #define NCO_MAX_GRP_DEPTH 10
 
-  /* Flag that iterator found no more groups in container */
+  /* Signifier that iterator found no more groups in container */
 #define NCO_LST_GRP 0
 
   /* Debugging level that quiets all non-requested informational messages
@@ -168,7 +168,8 @@ extern "C" {
 #define NCO_DBG_QUIET 0
 
   /* Find traversal table objects via hash table rather than brute-force strcmp() search */
-#define NCO_HSH_TRV_OBJ 1
+  /*#define NCO_HSH_TRV_OBJ */
+#undef NCO_HSH_TRV_OBJ
 
   /* NCO_MSS_VAL_SNG names attribute whose value is "skipped" by arithmetic, aka the missing value attribute
      Attribute name should be either "missing_value" or "_FillValue" */
@@ -280,7 +281,7 @@ extern "C" {
 # define NCO_VERSION_MINOR 4
 #endif /* !NCO_VERSION_MINOR */
 #ifndef NCO_VERSION_PATCH
-# define NCO_VERSION_PATCH 7
+# define NCO_VERSION_PATCH 8
 #endif /* !NCO_VERSION_PATCH */
 #ifndef NCO_VERSION_NOTE
 # define NCO_VERSION_NOTE  "" /* My be blank */
@@ -290,7 +291,7 @@ extern "C" {
 # define NCO_LIB_VERSION ( NCO_VERSION_MAJOR * 100 + NCO_VERSION_MINOR * 10 + NCO_VERSION_PATCH )
 #endif /* !NCO_LIB_VERSION */
 #ifndef NCO_VERSION
-# define NCO_VERSION "4.4.7"
+# define NCO_VERSION "4.4.8"
 #endif /* !NCO_VERSION */
 
 /* Compatibility tokens new to netCDF4 netcdf.h: */
@@ -550,6 +551,9 @@ extern "C" {
     nco_op_sqrt, /* [enm] Square root of mean */
     nco_op_rms, /* [enm] Root-mean-square (normalized by N) */
     nco_op_rmssdn, /* [enm] Root-mean square normalized by N-1 */
+    nco_op_mabs, /* [enm] Maximum absolute value */
+    nco_op_mebs, /* [enm] Mean absolute value */
+    nco_op_mibs, /* [enm] Minimum absolute value */
     nco_op_nil /* [enm] Nil or undefined operation type */
   }; /* end nco_op_typ enum */
 
@@ -935,7 +939,6 @@ extern "C" {
     nco_bool flg_xtr;        /* [flg] Extract dimension */
   } dmn_trv_sct; 
 
-
   /* Build a list of 'standard_name' 'latitude' and 'longitude' coordinates (Auxiliary Coordinates) */
   typedef struct{
     char *nm_fll;              /* [sng] Coordinate full name ('latitude' or 'longitude') */ 
@@ -1000,6 +1003,8 @@ extern "C" {
     int nbr_rec;                      /* [nbr] Number of record dimensions */
     int nbr_grp;                      /* [nbr] (For groups only) Number of sub-groups */   
     int nbr_var;                      /* [nbr] (For groups only) Number of variables */
+    int ppc;                          /* [nbr] Precision-preserving compression, i.e., number of total or decimal significant digits */
+    nco_bool flg_nsd;                 /* [flg] PPC is NSD */
 
     nco_bool flg_cf;                  /* [flg] Object matches CF-metadata extraction criteria */
     nco_bool flg_crd;                 /* [flg] Object matches coordinate extraction criteria */
@@ -1053,7 +1058,7 @@ extern "C" {
     long srt; /* [idx] Index to start of hyperslab */
     long sz; /* [nbr] Full size of dimension in file (NOT the hyperslabbed size) */
     nc_type type; /* [enm] Type of coordinate, if applicable */
-    ptr_unn val; /* [sct] Buffer to hold hyperslab fxm: is this ever used? */
+    ptr_unn val; /* [sct] Buffer to hold hyperslab (used by nco_prn to hold coordinate values) */
     short is_crd_dmn; /* [flg] Is this a coordinate dimension? */
     short is_rec_dmn; /* [flg] Is this the record dimension? */
     size_t cnk_sz; /* [nbr] Chunk size */
@@ -1067,7 +1072,6 @@ extern "C" {
     int var_nbr;            /* [nbr] Number of variable for this group (size of above array) */ 
   } nsm_grp_sct; 
 
-
   /* Ensemble (ncge) */
   typedef struct{
     char *grp_nm_fll_prn;   /* [sng] Parent group full name (key for ensemble) (e.g., /cesm) */
@@ -1080,7 +1084,6 @@ extern "C" {
     int mbr_srt;            /* [nbr] Member offsets, start (multi files, keep track of new added members) */ 
     int mbr_end;            /* [nbr] Member offsets, end (multi files, keep track of new added members) */ 
   } nsm_sct; 
-
   
   /* Name structure */
   typedef struct{ /* nm_sct */
@@ -1114,7 +1117,6 @@ extern "C" {
     char *var_nm_fll; /* [sng] Fully qualified variable name */
   } gpe_nm_sct;
 
-
   /* Common variable names; common defined as same absolute path in 2 files */
   typedef struct{		
     char *nm;                    /* [sng] A name */
