@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_aux.c,v 1.84 2014/10/31 17:55:56 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_aux.c,v 1.86 2015/02/04 04:16:24 zender Exp $ */
 
-/* Copyright (C) 1995--2014 Charlie Zender
+/* Copyright (C) 1995--2015 Charlie Zender
    This file is part of NCO, the netCDF Operators. NCO is free software.
-   You can redistribute and/or modify NCO under the terms of the 
+   You may redistribute and/or modify NCO under the terms of the 
    GNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file */
 
 /* Purpose: Support hyperslabbing cell-based grids over coordinate ranges 
@@ -354,10 +354,11 @@ nco_aux_prs
 #ifndef M_PI
 # define M_PI		3.14159265358979323846
 #endif /* M_PI */
-    *lon_min*=M_PI/180.0;
-    *lon_max*=M_PI/180.0;
-    *lat_min*=M_PI/180.0;
-    *lat_max*=M_PI/180.0;
+    const float dgr2rdn=M_PI/180.0;
+    *lon_min*=dgr2rdn;
+    *lon_max*=dgr2rdn;
+    *lat_min*=dgr2rdn;
+    *lat_max*=dgr2rdn;
   } /* endif radians */
 } /* nco_aux_prs */
 
