@@ -1,16 +1,16 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_cln_utl.c,v 1.48 2014/06/15 21:06:21 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_cln_utl.c,v 1.54 2015/02/03 17:58:35 zender Exp $ */
 
 /* Purpose: Calendar utilities */
 
-/* Copyright (C) 1995--2014 Charlie Zender
+/* Copyright (C) 1995--2015 Charlie Zender
    This file is part of NCO, the netCDF Operators. NCO is free software.
-   You can redistribute and/or modify NCO under the terms of the 
+   You may redistribute and/or modify NCO under the terms of the 
    GNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file */
 
 #include "nco_cln_utl.h" /* Calendar utilities */
 
 /* Arrays to hold calendar type units */
-/* Format: year,month,day,hour,min,sec,origin,offset */   
+/* Format: year, month, day, hour, minute, second, origin, offset */
 double DATA_360[8]={31104000.0,2592000.0,86400.0,3600.0,60.0,1,0.0,0.0};
 double DATA_365[8]={31536000.0,2628000.0,86400.0,3600.0,60.0,1,0.0,0.0};
 
@@ -52,8 +52,8 @@ nco_newdate /* [fnc] Compute date a specified number of days from input date */
   
   /* Local */
   const long mth_day_nbr[]= /* Number of days in each month */
-    { 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31,
-      31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 };
+    {31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31,
+     31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31};
   
   long day_nbr_2_eom; /* Days to end of month */
   long day_crr; /* Day of date */
@@ -151,11 +151,11 @@ nco_cln_clc_dff /* [fnc] UDUnits2 Compute difference between two coordinate unit
   int ut_rcd; /* [enm] UDUnits2 status */
   
   ut_system *ut_sys;
-  ut_unit *ut_sct_in; /* UDUnits structure, input units */
-  ut_unit *ut_sct_out; /* UDUnits structure, output units */
+  ut_unit *ut_sct_in; /* [sct] UDUnits structure, input units */
+  ut_unit *ut_sct_out; /* [sct] UDUnits structure, output units */
   
   /* Quick return if units identical */
-  if(!strcmp(fl_unt_sng,fl_bs_sng)){
+  if(!strcasecmp(fl_unt_sng,fl_bs_sng)){
     *og_val=crr_val;  
     return NCO_NOERR;
   } /* end if */
@@ -215,10 +215,11 @@ nco_cln_clc_dff /* [fnc] UDUnits2 Compute difference between two coordinate unit
 int /* [rcd] Successful conversion returns NCO_NOERR */
 nco_cln_prs_tm /* UDUnits2 Extract time stamp from parsed UDUnits string */
 (const char *unt_sng, /* I [ptr] units attribute string */
- tm_cln_sct *tm_in) /*  O [sct] struct to be populated */             
+ tm_cln_sct *tm_in) /* O [sct] Time structure to be populated */
 {
   const char fnc_nm[]="nco_cln_prs_tm()"; /* [sng] Function name */
 
+  /* 20141230: fxm figure out a better length */
   char bfr[200];
 
   char *dt_sng;
@@ -237,21 +238,22 @@ nco_cln_prs_tm /* UDUnits2 Extract time stamp from parsed UDUnits string */
     return NCO_ERR; /* Failure */
   } /* end if err */ 
 
-  /* units string to convert from */
+  /* Units string to convert from */
   ut_sct_in=ut_parse(ut_sys,unt_sng,UT_ASCII); 
   if(ut_sct_in == NULL){ /* Problem with 'units' attribute */
     ut_rcd=ut_get_status(); /* [enm] UDUnits2 status */
     if(ut_rcd == UT_BAD_ARG) (void)fprintf(stderr,"ERROR: empty units attribute string\n");
-    if(ut_rcd == UT_SYNTAX) (void)fprintf(stderr,"ERROR:  units attribute \"%s\" has a syntax error\n",unt_sng);
+    if(ut_rcd == UT_SYNTAX)  (void)fprintf(stderr,"ERROR: units attribute \"%s\" has a syntax error\n",unt_sng);
     if(ut_rcd == UT_UNKNOWN) (void)fprintf(stderr,"ERROR: units attribute \"%s\" is not listed in UDUnits2 SI system database\n",unt_sng);
 
     return NCO_ERR; /* Failure */
   } /* endif coordinate on disk has no units attribute */
 
   /* Print timestamp to buffer in standard, dependable format */
-  ut_format(ut_sct_in,bfr,sizeof(bfr), UT_ASCII|UT_NAMES);
+  ut_format(ut_sct_in,bfr,sizeof(bfr),UT_ASCII|UT_NAMES);
 
-  /* Extract parsed time units from print string (kludgy) */
+  /* Extract parsed time units from print string (kludgy)
+     20141230 change to using ut_decode_time() instead? */
   dt_sng=strstr(bfr,"since");  
   sscanf(dt_sng,"%*s %d-%d-%d %d:%d:%f",&tm_in->year,&tm_in->month,&tm_in->day,&tm_in->hour,&tm_in->min,&tm_in->sec);
 
@@ -339,10 +341,10 @@ nco_cln_clc_dff /* [fnc] UDUnits1 Difference between two co-ordinate units */
   return NCO_NOERR;   
 }  /* end UDUnits1 nco_cln_clc_dff() */
 
-int /* [rcd] Successful conversion returns NCO_NOERR */     
+int /* [rcd] Successful conversion returns NCO_NOERR */
 nco_cln_prs_tm /* UDUnits1 Extract time stamp from a parsed udunits string */
-(const char *unt_sng, /* I [ptr] units attribute string   */            
-tm_cln_sct *tm_in) /*  O [sct] struct to be populated   */             
+(const char *unt_sng, /* I [ptr] units attribute string */
+ tm_cln_sct *tm_in) /* O [sct] Time structure to be populated */
 {
   const char fnc_nm[]="nco_cln_prs_tm()"; /* [sng] Function name */
 
@@ -364,7 +366,7 @@ tm_cln_sct *tm_in) /*  O [sct] struct to be populated   */
     return NCO_ERR;
   } /* end if err */ 
 
-  /* units string to convert from */
+  /* Units string to convert from */
   rcd=utScan(unt_sng,&udu_sct_in); 
   if(rcd != UDUNITS_NOERR){
     if(rcd == UT_EINVALID) (void)fprintf(stderr,"ERROR: units attribute \"%s\" is invalid \n",unt_sng);
@@ -387,7 +389,7 @@ tm_cln_sct *tm_in) /*  O [sct] struct to be populated   */
 
 } /* end UDUnits1 nco_cln_prs_tm() */
 
-# endif /*!HAVE_UDUNITS2 */
+# endif /* !HAVE_UDUNITS2 */
 
 #else /* !ENABLE_UDUNITS */
 
@@ -401,23 +403,23 @@ const char *fl_unt_sng, /* I [ptr] units attribute string from disk  */
 const char *fl_bs_sng, /* I [ptr] units attribute string from disk  */     
 double crr_val,
 double *og_val){ /* O [ptr] */
-return NCO_NOERR;
+  return NCO_NOERR;
 }
 
 int /* [rcd] Successful conversion returns NCO_NOERR */     
 nco_cln_prs_tm( /* Extract time stamp from a parsed UDUnits string */
 const char *unt_sng, /* I [ptr] units attribute string */
 tm_cln_sct *tm_in){ /* O [sct] struct to be populated */             
-return NCO_NOERR;
+  return NCO_NOERR;
 }
 
 #endif /* !ENABLE_UDUNITS */
 
 /* End UDUnits-related routines*/
  
-tm_typ /* [enum] Units type */    
+tm_typ /* O [enm] Units type */
 nco_cln_get_tm_typ /* Returns time unit type or tm_void if not found */
-(const char *ud_sng){ /* I [ptr] units string  */      
+(const char *ud_sng){ /* I [ptr] Units string  */
   int idx;
   int len; 
   char *lcl_sng;  
@@ -425,7 +427,7 @@ nco_cln_get_tm_typ /* Returns time unit type or tm_void if not found */
   
   lcl_sng=strdup(ud_sng);
   
-  /* Initially set ret type to void */
+  /* Set initial return type to void and overwrite */
   rcd_typ=tm_void;   
   
   /* Convert to lower case */
@@ -443,9 +445,9 @@ nco_cln_get_tm_typ /* Returns time unit type or tm_void if not found */
   return rcd_typ;
 } /* end nco_cln_get_tm_typ() */
 
-nco_cln_typ /* [enum] Calendar type */    
-nco_cln_get_cln_typ /*  [fnc]  Calendar type or cln_nil if not found */
-(const char *ud_sng) /* I [ptr] units string  */      
+nco_cln_typ /* [enm] Calendar type */
+nco_cln_get_cln_typ /* [fnc] Determine calendar type or cln_nil if not found */
+(const char *ud_sng) /* I [ptr] units string  */
 {
   int idx;
   int len; 
@@ -456,7 +458,7 @@ nco_cln_get_cln_typ /*  [fnc]  Calendar type or cln_nil if not found */
   
   lcl_sng=strdup(ud_sng);
   
-  /* Initially set return type to void */
+  /* Set initial return type to void then overwrite */
   rcd_typ=cln_nil;
   
   /* Convert to lower case */
@@ -512,6 +514,7 @@ void
 nco_cln_pop_val /* [fnc] Calculate value in cln_sct */ 
 (tm_cln_sct *cln_sct) /* I/O [ptr] structure */
 {
+  /* Purpose: Populate values in calendar structure */
   double *data;
   
   switch(cln_sct->sc_cln){
@@ -540,7 +543,7 @@ nco_cln_pop_val /* [fnc] Calculate value in cln_sct */
   case cln_jul:
   case cln_nil:
     break;
-  }
+  } /* end switch */
   
   return;
 } /* end nco_cln_pop_val() */
@@ -598,15 +601,16 @@ nco_cln_rel_val
 
 int /* [rcd] Successful conversion returns NCO_NOERR */
 nco_cln_clc_tm /* [fnc] Difference between two coordinate units */
-(const char *fl_unt_sng, /* I [ptr] units attribute string from disk */
- const char *fl_bs_sng, /* I [ptr] units attribute string from disk */
- nco_cln_typ lmt_cln, /* [enum] Calendar type of coordinate var */ 
+(const char *fl_unt_sng, /* I [ptr] Units attribute string from disk */
+ const char *fl_bs_sng, /* I [ptr] Units attribute string from disk */
+ nco_cln_typ lmt_cln, /* [enum] Calendar type of coordinate variable */ 
  double *og_val){ /* O [ptr] */
   
   int rcd;
   int year;
   int month;
   char *lcl_unt_sng;
+  /* 20141230 figure out better length */
   char tmp_sng[100];
   double crr_val;
   
@@ -639,7 +643,6 @@ nco_cln_clc_tm /* [fnc] Difference between two coordinate units */
   
   /* Assume non-standard calendar */ 
   if(nco_cln_prs_tm(lcl_unt_sng,&unt_cln_sct) == NCO_ERR) return NCO_ERR;
-  
   if(nco_cln_prs_tm(fl_bs_sng,&bs_cln_sct) == NCO_ERR) return NCO_ERR;
   
   unt_cln_sct.sc_typ=bs_tm_typ;
@@ -677,7 +680,7 @@ nco_cln_clc_org /* [fnc] Difference between two generic co-ordinate units */
   double crr_val;
   
   /* If units contain date or timestamp call special time-conversion routine */
-  if(strstr(fl_bs_sng," from ") || strstr(fl_bs_sng," since ") || strstr(fl_bs_sng," after ")){
+  if(strcasestr(fl_bs_sng," from ") || strcasestr(fl_bs_sng," since ") || strcasestr(fl_bs_sng," after ")){
     rcd=nco_cln_clc_tm(fl_unt_sng,fl_bs_sng,lmt_cln,og_val);   
     return rcd;
   } /* endif */
@@ -689,3 +692,92 @@ nco_cln_clc_org /* [fnc] Difference between two generic co-ordinate units */
   usr_unt_sng=(char *)nco_free(usr_unt_sng);
   return rcd;  
 } /* end nco_cln_clc_org() */
+
+int /* O [flg] String is calendar date */
+nco_cln_chk_tm /* [fnc] Is string a UDUnits-compatible calendar format, e.g., "PERIOD since REFERENCE_DATE" */
+(const char *unit_sng) /* I [sng] Units string */
+{
+  /* Purpose:
+     Determine whether the string is a UDUnits-compatible calendar format, e.g., "PERIOD since REFERENCE_DATE" */
+
+  /* Does string contain date keyword? */
+  if(strcasestr(unit_sng," from ") || strcasestr(unit_sng," since ") || strcasestr(unit_sng," after ")) return True; else return False;
+
+} /* end nco_cln_chk_tm() */
+
+int /* [rcd] Return code */
+nco_cln_sng_rbs /* [fnc] Rebase calendar string for legibility */
+(const ptr_unn val, /* I [sct] Value to rebase */
+ const long val_idx, /* I [idx] Index into 1-D array of values */
+ const nc_type val_typ, /* I [enm] Value type */
+ const char *unit_sng, /* I [sng] Units string */
+ char *lgb_sng) /* O [sng] Legible version of input string */
+{
+  /* Purpose: Rebase calendar string for legibility
+     Assumptions: Input units string unit_sng is a calendar date, i.e., contains "from", "since", or "after"
+
+     ncdump handles this in nctime0.c
+     dumplib.c/nctime_val_tostring() by Dave Allured, NOAA
+     cdRel2Iso() from CDMS by Bob Drach, LLNL
+     cdParseRelunits() from CDMS by Bob Drach, LLNL */
+
+#ifdef HAVE_UDUNITS2_H
+
+  const char fnc_nm[]="nco_cln_sng_rbs()"; /* [sng] Function name */
+  
+  double val_dbl; /* [day] Calendar offset converted to double */
+
+  int ut_rcd; /* [enm] UDUnits2 status */
+  
+  ut_system *ut_sys;
+  ut_unit *ut_sct_in; /* [sct] UDUnits structure, input units */
+  ut_unit *ut_sct_out; /* [sct] UDUnits structure, output units */
+
+  /* Quick return if units DNE */
+  if(!unit_sng) return NCO_NOERR;
+  
+  /* When empty, ut_read_xml() uses environment variable UDUNITS2_XML_PATH, if any
+     Otherwise it uses default initial location hardcoded when library was built */
+  if(nco_dbg_lvl_get() >= nco_dbg_vrb) ut_set_error_message_handler(ut_write_to_stderr); else ut_set_error_message_handler(ut_ignore);
+  ut_sys=ut_read_xml(NULL);
+  if(!ut_sys){
+    (void)fprintf(stdout,"%s: %s() failed to initialize UDUnits2 library\n",nco_prg_nm_get(),fnc_nm);
+    return NCO_ERR; /* Failure */
+  } /* end if err */ 
+
+  /* Units string containing calendar origin converted to UDUnit structure */
+  ut_sct_in=ut_parse(ut_sys,unit_sng,UT_ASCII); 
+  if(!ut_sct_in){ /* Problem with 'units' attribute */
+    ut_rcd=ut_get_status(); /* [enm] UDUnits2 status */
+    if(ut_rcd == UT_BAD_ARG) (void)fprintf(stderr,"ERROR: empty units attribute string\n");
+    if(ut_rcd == UT_SYNTAX) (void)fprintf(stderr,"ERROR: units attribute \"%s\" has a syntax error\n",unit_sng);
+    if(ut_rcd == UT_UNKNOWN) (void)fprintf(stderr,"ERROR: units attribute \"%s\" is not listed in UDUnits2 SI system database\n",unit_sng);
+    return NCO_ERR; /* Failure */
+  } /* endif coordinate on disk has no units attribute */
+
+  /* Convert time since calendar origin to double */
+  val_dbl=ptr_unn_2_scl_dbl(val,val_typ); 
+  
+  /* Units string to convert to */
+  ut_sct_out=ut_offset(ut_sct_in,val_dbl);
+  if(!ut_sct_out){ /* Problem with 'units' attribute */
+    ut_rcd=ut_get_status(); /* [enm] UDUnits2 status */
+    if(ut_rcd == UT_BAD_ARG) (void)fprintf(stderr,"ERROR: Empty units attribute string\n");
+    if(ut_rcd == UT_SYNTAX) (void)fprintf(stderr,"ERROR: units attribute  \"%s\" has a syntax error\n",unit_sng);
+    if(ut_rcd == UT_UNKNOWN) (void)fprintf(stderr,"ERROR: units attribute \"%s\" is not listed in UDUnits2 SI system database\n",unit_sng);
+    return NCO_ERR; /* Failure */
+  } /* endif */
+
+  val_dbl+=0*val_idx; /* CEWI */
+
+  ut_free(ut_sct_in);
+  ut_free(ut_sct_out);
+  ut_free_system(ut_sys); /* Free memory taken by UDUnits library */
+#endif /* !HAVE_UDUNITS2 */
+
+  lgb_sng[0]='\0'; /* CEWI */
+
+  return NCO_NOERR;
+
+} /* end nco_cln_sng_rbs() */
+
