@@ -1,10 +1,10 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_cnk.c,v 1.151 2014/11/26 04:15:26 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_cnk.c,v 1.157 2015/02/04 04:16:24 zender Exp $ */
 
 /* Purpose: NCO utilities for chunking */
 
-/* Copyright (C) 1995--2014 Charlie Zender
+/* Copyright (C) 1995--2015 Charlie Zender
    This file is part of NCO, the netCDF Operators. NCO is free software.
-   You can redistribute and/or modify NCO under the terms of the 
+   You may redistribute and/or modify NCO under the terms of the 
    GNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file */
 
 /* Usage:
@@ -211,6 +211,7 @@ nco_cnk_ini /* [fnc] Create structure with all chunking information */
   /* NCO-recommended chunking map is expected to change over time
      cnk_map=nco assigns current NCO-recommended map */
   if(cnk_map == nco_cnk_map_nco) cnk->cnk_map=nco_cnk_map_rd1;
+  if(cnk_map == nco_cnk_plc_nco) cnk->cnk_plc=nco_cnk_plc_nco;
 
   return rcd;
 } /* end nco_cnk_ini() */
@@ -328,7 +329,7 @@ nco_cnk_map_get /* [fnc] Convert user-specified chunking map to key */
 
   if(nco_cnk_map_sng == NULL){
     /* 20140815: Change default from rd1 to xst */
-    if(nco_dbg_lvl_get() >= nco_dbg_std) (void)fprintf(stdout,"%s: INFO %s reports %s invoked without explicit chunking map. Defaulting to chunking map \"xst\".\n",nco_prg_nm,fnc_nm,nco_prg_nm);
+    if(nco_dbg_lvl_get() >= nco_dbg_scl) (void)fprintf(stdout,"%s: INFO %s reports %s invoked without explicit chunking map. Defaulting to chunking map \"xst\".\n",nco_prg_nm,fnc_nm,nco_prg_nm);
     return nco_cnk_map_xst;
   } /* endif */
 
@@ -370,7 +371,7 @@ nco_cnk_plc_get /* [fnc] Convert user-specified chunking policy to key */
 
   if(nco_cnk_plc_sng == NULL){
     /* 20140815: Change default from g2d to xst */
-    if(nco_dbg_lvl_get() >= nco_dbg_std) (void)fprintf(stdout,"%s: INFO %s reports %s invoked without explicit chunking policy. Defaulting to chunking policy \"xst\".\n",nco_prg_nm,fnc_nm,nco_prg_nm);
+    if(nco_dbg_lvl_get() >= nco_dbg_scl) (void)fprintf(stdout,"%s: INFO %s reports %s invoked without explicit chunking policy. Defaulting to chunking policy \"xst\".\n",nco_prg_nm,fnc_nm,nco_prg_nm);
     return nco_cnk_plc_xst;
   } /* endif */
 
@@ -877,7 +878,7 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
     nco_exit(EXIT_FAILURE);
   } /* endif cnk_sz_scl */
 
-  if(FIRST_CALL && nco_dbg_lvl_get() >= nco_dbg_fl && nco_dbg_lvl_get() != nco_dbg_dev){
+  if(FIRST_CALL && nco_dbg_lvl_get() >= nco_dbg_scl && nco_dbg_lvl_get() != nco_dbg_dev){
     (void)fprintf(stdout,"%s: INFO User requested chunking or unchunking\n",nco_prg_nm_get());
     if(nco_dbg_lvl_get() >= nco_dbg_scl  && nco_dbg_lvl_get() != nco_dbg_dev){
       (void)fprintf(stdout,"cnk_plc, cnk_map: %s, %s\n",nco_cnk_plc_sng_get(cnk_plc),nco_cnk_map_sng_get(cnk_map));
@@ -1085,7 +1086,11 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
 
   } /* end loop over dimensions */
 
-  if(cnk_map == nco_cnk_map_lfp){
+  //cnk_map_lfp: /* end goto */
+
+  if(cnk_map == nco_cnk_map_lfp ||
+     (cnk_plc == nco_cnk_plc_nco && dmn_nbr != 3) ||
+     (cnk_map == nco_cnk_map_rew && dmn_nbr != 3)){
     /* Set "Lefter Product" chunksizes
        Reasonable defaults have been set for all dimensions, now adjust lefter dimensions to match overall size */
     int dmn_idx_1st_rec;
@@ -1118,10 +1123,13 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
     goto cnk_xpl_override;
   } /* !nco_cnk_map_lfp */
 
-  if(cnk_map == nco_cnk_map_rew){
+  //cnk_map_rew: /* end goto */
 
-    /* Apply only to 3-D variables */
-    if(dmn_nbr != 3) goto cnk_xpl_override;
+  /* Apply Rew only to 3-D variables */
+  if(cnk_map == nco_cnk_map_rew && dmn_nbr != 3) goto cnk_xpl_override;
+
+  if(cnk_map == nco_cnk_map_rew || 
+     (cnk_plc == nco_cnk_plc_nco && dmn_nbr == 3)){
 
     /* Implementation by Russ Rew at http://www.unidata.ucar.edu/staff/russ/public/chunk_shape_3D.py
        >>> import cnk
@@ -1135,6 +1143,7 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
     double cnk_nbr_xct; /* [nbr] Exact number of ideal chunks needed to store variable */
     double cnk_nbr_2D_axs; /* [nbr] Exact number of ideal chunks along each 2D axis */
     double fct_ncr=1.0; /* [frc] Factor by which to increase chunk size */
+    double cnk_sz_rgn_zro_dfl; /* [nbr] Default chunk size for dimension zero (time) */
     size_t *cnk_sz_prt; /* [nbr] Perturbed chunk size (base chunk size plus zero or one) */
     size_t *cnk_sz_rgn; /* [nbr] Original (first-guess) chunk size (no adjustments) */
     size_t *prt_cff; /* [nbr] Rerturbation to base chunk size for each dimension, also [0,1] multiplier for each power of two in this permutation index */
@@ -1156,20 +1165,28 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
       dmn_sz_prd*=var_shp[dmn_idx];
     } /* end loop over dmn_idx */
     
+    /* [nbr] Exact number of ideal chunks needed to store variable */
     cnk_nbr_xct=dmn_sz_prd/cnk_val_nbr;
+    /* [nbr] Exact number of ideal chunks along each 2D axis */
     cnk_nbr_2D_axs=pow(cnk_nbr_xct,0.25);
+    /* Default chunk size for dimension zero (time) */
+    cnk_sz_rgn_zro_dfl=var_shp[0]/(cnk_nbr_2D_axs*cnk_nbr_2D_axs);
 
-    if(var_shp[0]/(cnk_nbr_2D_axs*cnk_nbr_2D_axs) < 1.0){
-      cnk_sz_rgn[0]=1L;
-      cnk_nbr_2D_axs/=sqrt((double)var_shp[0]/(cnk_nbr_2D_axs*cnk_nbr_2D_axs));
+    if(var_shp[0]/(cnk_nbr_2D_axs*cnk_nbr_2D_axs) >= 1.0){
+      cnk_sz_rgn[0]=(size_t)cnk_sz_rgn_zro_dfl; // Here Rew13 uses Python // operator for integer arithmetic
     }else{
-      cnk_sz_rgn[0]=var_shp[0]/(cnk_nbr_2D_axs*cnk_nbr_2D_axs); // Rew13 uses // for integer arithmetic here
+      /* Adjust chunk shape because time-series length incommensurate with lateral dimensions:
+	 If default chunk shape would give time chunk size smaller than one, then set time chunk size equal to one
+	 (larger than default) and compensate for effect of this in overall chunk volume by shrinking 
+	 lateral size by same factor such that product of adjusted chunk sizes equals product of default chunk sizes */
+      cnk_sz_rgn[0]=1L;
+      cnk_nbr_2D_axs/=sqrt(cnk_sz_rgn_zro_dfl);
     } /* endif */
 
-    for(dmn_idx=1;dmn_idx<=dmn_nbr-1;dmn_idx++) /* NB: Start at 1 */
+    for(dmn_idx=1;dmn_idx<=dmn_nbr-1;dmn_idx++) /* NB: Start at index 1 */
       if(var_shp[dmn_idx]/cnk_nbr_2D_axs < 1.0) fct_ncr*=cnk_nbr_2D_axs/var_shp[dmn_idx];
-    for(dmn_idx=1;dmn_idx<=dmn_nbr-1;dmn_idx++) /* NB: Start at 1 */
-      if(var_shp[dmn_idx]/cnk_nbr_2D_axs < 1.0) cnk_sz_rgn[dmn_idx]=1L; else cnk_sz_rgn[dmn_idx]=fct_ncr*var_shp[dmn_idx]/cnk_nbr_2D_axs;
+    for(dmn_idx=1;dmn_idx<=dmn_nbr-1;dmn_idx++) /* NB: Start at index 1 */
+      if(var_shp[dmn_idx]/cnk_nbr_2D_axs < 1.0) cnk_sz_rgn[dmn_idx]=1L; else cnk_sz_rgn[dmn_idx]=(size_t)(fct_ncr*var_shp[dmn_idx]/cnk_nbr_2D_axs);
 
     /* First-guess estimate of chunk size */
     size_t cnk_sz_prd=1L;
@@ -1187,13 +1204,13 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
     size_t prm_idx; /* [idx] Permutation index [0..2^(dmn_nbr-1)] */
     size_t prt_sum; /* [nbr] Partial sum (sum of coefficients times powers of two for higher powers */
     /* Score initial guess */
-    cnk_gap=cnk_sz_byt-cnk_sz_prd*typ_sz;
+    cnk_gap=(long)(cnk_sz_byt-cnk_sz_prd*typ_sz);
     /* In case initial guess is lucky and permutation loop breaks before completing */
     for(dmn_idx=0;dmn_idx<=dmn_nbr-1;dmn_idx++) cnk_sz[dmn_idx]=cnk_sz_rgn[dmn_idx];
 
     /* Loop through permutations of adjusting first-estimate chunk size by plus one
        NB: Skip permutation prm_idx=0 since it is degenerate and does not change first-guess chunk sizes */
-    for(prm_idx=1;prm_idx<two_pwr_rnk;prm_idx++){ /* NB: Loop starts at 1 to skip degenerate perumutation */
+    for(prm_idx=1;prm_idx<two_pwr_rnk;prm_idx++){ /* NB: Loop starts at 1 to skip degenerate permutation */
       if(cnk_gap == 0L) break;
       cnk_sz_prd=1L;
       /* Fill-in coefficient from MSB to LSB */
@@ -1207,7 +1224,7 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
 	cnk_sz_prd*=cnk_sz_prt[dmn_idx];
       } /* dmn_idx */
       /* Test gap narrowness */
-      cnk_gap_prt=cnk_sz_byt-cnk_sz_prd*typ_sz;
+      cnk_gap_prt=(long)(cnk_sz_byt-cnk_sz_prd*typ_sz);
 
       if(nco_dbg_lvl_get() >= nco_dbg_var){
 	(void)fprintf(stdout,"prm_idx = %lu, cnk_gap = %ld, cnk_sz_prd = %lu, cnk_gap_prt = %ld, prt_sum = %lu\n",(unsigned long)prm_idx,cnk_gap,(unsigned long)cnk_sz_prd,cnk_gap_prt,(unsigned long)prt_sum);
@@ -1238,8 +1255,14 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
     if(two_pwr_idx) two_pwr_idx=(size_t *)nco_free(two_pwr_idx); 
     if(var_shp) var_shp=(size_t *)nco_free(var_shp); 
 
+    /* Skip uniform and per-dimension overrides, go straight to final safety check */
+    goto cnk_sft_chk;
+
   } /* !nco_cnk_map_rew */
 
+  /* Uniform override */
+  // cnk_unf_override: /* end goto */
+
   /* Override "reasonable" defaults with explicitly set uniform scalar chunksize, if any */
   if(cnk_sz_dfl > 0UL){
     for(dmn_idx=0;dmn_idx<dmn_nbr;dmn_idx++){
@@ -1260,7 +1283,8 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
     } /* end loop over dimensions */
   } /* !cnk_sz_dfl */
 
-cnk_xpl_override: /* end goto */
+  /* Explicit (per-dimension) override */
+ cnk_xpl_override: /* end goto */
 
   /* Override "reasonable" defaults with explicitly set per-dimension sizes, if any */
   for(dmn_idx=0;dmn_idx<dmn_nbr;dmn_idx++){
@@ -1322,6 +1346,9 @@ cnk_xpl_override: /* end goto */
 
   } /* end loop over dmn_idx */
 
+  /* Final Safety Check */
+ cnk_sft_chk: /* end goto */
+
   /* Status: Previous loop implemented per-dimension checks on user-requested chunksizes only
      Loop below implements similar final safety check for ALL dimensions and ALL chunking maps
      Check trims fixed (not record) dimension chunksize to never be larger than dimension size */
@@ -1329,7 +1356,7 @@ cnk_xpl_override: /* end goto */
     if(cnk_sz[dmn_idx] > (size_t)dmn_cmn[dmn_idx].sz){
       if(!dmn_cmn[dmn_idx].is_rec_dmn){
         /* Unlike record dimensions, non-record dimensions must have cnk_sz <= dmn_sz */
-        if(nco_dbg_lvl_get() >= nco_dbg_std) (void)fprintf(stderr,"%s: INFO %s final check trimming chunksize of \"%s\" dimension from %lu to %lu\n",nco_prg_nm_get(),fnc_nm,dmn_cmn[dmn_idx].nm,(unsigned long)cnk_sz[dmn_idx],(unsigned long)dmn_cmn[dmn_idx].sz);
+        if(nco_dbg_lvl_get() >= nco_dbg_var) (void)fprintf(stderr,"%s: INFO %s final check trimming chunksize of \"%s\" dimension from %lu to %lu\n",nco_prg_nm_get(),fnc_nm,dmn_cmn[dmn_idx].nm,(unsigned long)cnk_sz[dmn_idx],(unsigned long)dmn_cmn[dmn_idx].sz);
         /* Trim else out-of-bounds sizes will fail in HDF library in nc_enddef() */
         cnk_sz[dmn_idx]=(size_t)dmn_cmn[dmn_idx].sz;
       } /* rcd_dmn_id */
