@@ -1,10 +1,10 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_cnk.h,v 1.42 2014/10/17 15:42:40 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_cnk.h,v 1.44 2015/02/03 02:08:55 zender Exp $ */
 
 /* Purpose: Description (definition) of chunking functions */
 
-/* Copyright (C) 1995--2014 Charlie Zender
+/* Copyright (C) 1995--2015 Charlie Zender
    This file is part of NCO, the netCDF Operators. NCO is free software.
-   You can redistribute and/or modify NCO under the terms of the 
+   You may redistribute and/or modify NCO under the terms of the 
    GNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file */
 
 /* Usage:
@@ -38,7 +38,8 @@ enum nco_cnk_plc{ /* [enm] Chunking policy */
   nco_cnk_plc_xpl, /* 4 [enm] Chunk variables with explicitly chunked dimensions */
   nco_cnk_plc_xst, /* 5 [enm] Chunk variables that are chunked in input */
   nco_cnk_plc_uck, /* 6 [enm] Unchunk all chunked variables */
-  nco_cnk_plc_r1d /* 7 [enm] Chunk record coordinates == one dimension */
+  nco_cnk_plc_r1d, /* 7 [enm] Chunk record coordinates == one dimension */
+  nco_cnk_plc_nco /* 8 [enm] Chunk variables according to current "best" NCO algorithm */
 }; /* end nco_cnk_plc enum */
 
 /* Chunking type maps: */
