@@ -1,10 +1,10 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_grp_trv.c,v 1.298 2014/06/15 21:06:23 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_grp_trv.c,v 1.311 2015/02/04 02:44:45 zender Exp $ */
 
 /* Purpose: netCDF4 traversal storage */
 
-/* Copyright (C) 1995--2014 Charlie Zender
+/* Copyright (C) 1995--2015 Charlie Zender
    This file is part of NCO, the netCDF Operators. NCO is free software.
-   You can redistribute and/or modify NCO under the terms of the 
+   You may redistribute and/or modify NCO under the terms of the 
    GNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file */
 
 /* This file contains the API for low level group data structures:
@@ -192,7 +192,6 @@ trv_tbl_free                           /* [fnc] GTT free memory */
 #ifdef DEBUG_LEAKS
   if(nco_dbg_lvl_get() >= nco_dbg_sup)(void)fprintf(stdout,"%s: DEBUG %s %d crd",nco_prg_nm_get(),fnc_nm,crt_counter);
 #endif
-
 } /* end trv_tbl_free() */
 
 void                       
@@ -295,6 +294,26 @@ trv_tbl_prn                          /* [fnc] Print table with -z */
   } /* end idx_tbl */
 } /* end trv_tbl_prn() */
 
+char *                                /* O [flg] Full variable name */
+nco_gid_var_nm_2_var_nm_fll           /* [fnc] Construct full variable name from group ID and variable name */
+(const int grp_id,                    /* I [ID] netCDF input group ID */
+ const char * const var_nm)           /* I [sng] Variable name */
+{
+  char *var_nm_fll;
+  size_t grp_nm_lng;
+  size_t var_nm_fll_lng;
+  (void)nco_inq_grpname_full(grp_id,&grp_nm_lng,NULL);
+  /* Groups except root need a slash character to separate their name from variable name */
+  var_nm_fll_lng=grp_nm_lng+strlen(var_nm);
+  if(grp_nm_lng != 1L) var_nm_fll_lng++;
+  /* One extra space for NUL-terminator */
+  var_nm_fll=(char *)nco_malloc(var_nm_fll_lng+1L);
+  (void)nco_inq_grpname_full(grp_id,NULL,var_nm_fll);
+  if(grp_nm_lng != 1L) strcat(var_nm_fll,"/");
+  strcat(var_nm_fll,var_nm);
+  return var_nm_fll;
+} /* end nco_gid_var_nm_2_var_nm_fll() */
+
 nco_bool                              /* O [flg] Item found or not */
 trv_tbl_fnd_var_nm_fll                /* [fnc] Check if "var_nm_fll" is in table */
 (const char * const var_nm_fll,       /* I [sng] Variable name to find */
@@ -846,10 +865,10 @@ trv_tbl_mrk_nsm_mbr                    /* [fnc] Mark ensemble member flag in tab
  trv_tbl_sct * const trv_tbl)          /* I/O [sct] Traversal table */
 {
   for(unsigned idx_tbl=0;idx_tbl<trv_tbl->nbr;idx_tbl++){
-    if(trv_tbl->lst[idx_tbl].nco_typ == nco_obj_typ_var && strcmp(var_nm_fll,trv_tbl->lst[idx_tbl].nm_fll) == 0){
+    if(trv_tbl->lst[idx_tbl].nco_typ == nco_obj_typ_var && !strcmp(var_nm_fll,trv_tbl->lst[idx_tbl].nm_fll)){
       trv_tbl->lst[idx_tbl].flg_nsm_mbr=True;
       trv_tbl->lst[idx_tbl].nsm_nm=strdup(grp_nm_fll_prn);
-      if (flg_nsm_tpl) trv_tbl->lst[idx_tbl].flg_nsm_tpl=True;
+      if(flg_nsm_tpl) trv_tbl->lst[idx_tbl].flg_nsm_tpl=True;
     }
   }
 
@@ -871,30 +890,21 @@ nco_bld_nm_fll                         /* [fnc] Utility function to build a full
   strcat(var_nm_fll,var_nm);
 
   return var_nm_fll;
-
 } /* nco_bld_nm_fll() */
 
-
 nco_bool                              
 nco_lst_ins                            /* [fnc] Utility function to detect inserted names in a name list */
 (const char * const nm,                /* I [sng] A name to detect */
  const nco_cmn_t *cmn_lst,             /* I [sct] List of names   */
  const int nbr_nm)                     /* I [nbr] Number of names (size of above array) */
 {
-  /* Loop constructed array to see if already inserted */
-  for(int idx_nm=0;idx_nm<nbr_nm;idx_nm++){
-      /* Match */
-      if(strcmp(cmn_lst[idx_nm].nm,nm) == 0){
-        /* Mark as inserted in array */
-        return True;
-      }  /* Match */
-  } /* Loop constructed array to see if already inserted  */
+  /* If match then mark as inserted in array */
+  for(int idx_nm=0;idx_nm<nbr_nm;idx_nm++)
+    if(!strcmp(cmn_lst[idx_nm].nm,nm)) return True;
 
   return False;
-
 } /* nco_lst_ins() */
 
-
 char *                                 /* O [sng] Full path with suffix */
 nco_bld_nsm_sfx                        /* [fnc] Build ensemble suffix */
 (const char * const grp_nm_fll_prn,    /* I [sng] Absolute group name of ensemble root */
@@ -904,8 +914,7 @@ nco_bld_nsm_sfx                        /* [fnc] Build ensemble suffix */
 
   /* Loop table */
   for(unsigned tbl_idx=0;tbl_idx<trv_tbl->nbr;tbl_idx++){
-    /* Match */
-    if(trv_tbl->lst[tbl_idx].nco_typ == nco_obj_typ_grp && strcmp(grp_nm_fll_prn,trv_tbl->lst[tbl_idx].nm_fll) == 0){
+    if(trv_tbl->lst[tbl_idx].nco_typ == nco_obj_typ_grp && !strcmp(grp_nm_fll_prn,trv_tbl->lst[tbl_idx].nm_fll)){
 
       /* Define (append) a new name */
       char *nm_fll_sfx=(char*)nco_malloc(strlen(grp_nm_fll_prn)+strlen(trv_tbl->lst[tbl_idx].nm)+strlen(trv_tbl->nsm_sfx)+2L);
@@ -918,10 +927,8 @@ nco_bld_nsm_sfx                        /* [fnc] Build ensemble suffix */
     } /* Match */
   } /* Loop table*/
 
-
   assert(0);
   return NULL;
-
 } /* nco_bld_nsm_sfx() */
 
 nco_bool                              
@@ -930,47 +937,26 @@ nco_is_fll_pth                         /* [fnc] Utility function to inquire if a
 {
   const char *sbs_srt; /* [sng] Location of string match start in parameter string */
 
-  /* If parameter string contains any slash character '/' , assume it's a full path */
+  /* If parameter string contains any slash character '/' , assume it is a full path */
   sbs_srt=strstr(str,"/");
-  if (sbs_srt) return True;
+  if(sbs_srt) return True;
   return False;
-
 } /* nco_is_fll_pth() */
 
-
-char *
-nco_strrstr                            /* [fnc] Searches a substring starting from the end */
-(const char *str,                      /* [fnc] String */
- const char *str_fnd)                  /* [fnc] String to find */
-{
-  char *ptr;
-  char *lst=NULL;
-
-  ptr = (char*)str;
-  while((ptr = strstr(ptr, str_fnd))){
-    lst = ptr++;
-  }
-  return lst;
-} /* nco_strrstr() */
-
-
 trv_sct *                             /* O [sct] Table object */
 trv_tbl_var_nm                        /* [fnc] Return variable object (relative name) */
 (const char * const var_nm,           /* I [sng] Variable name to find */
  const trv_tbl_sct * const trv_tbl)   /* I [sct] Traversal table */
 {
-  /* Purpose: Return variable object with given relative name (returns 1st name found ) */
-
+  /* Purpose: Return variable object with given relative name (returns 1st name found) 
+     NB: Calling this function is almost certainly a mistake */
   for(unsigned idx_tbl=0;idx_tbl<trv_tbl->nbr;idx_tbl++)
-    if(trv_tbl->lst[idx_tbl].nco_typ == nco_obj_typ_var && (strcmp(var_nm,trv_tbl->lst[idx_tbl].nm) == 0)){
+    if(trv_tbl->lst[idx_tbl].nco_typ == nco_obj_typ_var && !strcmp(var_nm,trv_tbl->lst[idx_tbl].nm))
       return &trv_tbl->lst[idx_tbl];
-    }
-
-    return NULL;
 
+  return NULL;
 } /* trv_tbl_var_nm() */
 
-
 trv_sct *                              /* O [sct] Table object */
 trv_tbl_nsm_nm                         /* [fnc] Return variable object  */
 (const char * const var_nm,            /* I [sng] Variable name (relative) to find */
@@ -981,20 +967,14 @@ trv_tbl_nsm_nm                         /* [fnc] Return variable object  */
 
   for(unsigned idx_tbl=0;idx_tbl<trv_tbl->nbr;idx_tbl++){
     trv_sct var_trv=trv_tbl->lst[idx_tbl];  
-    if(var_trv.nco_typ == nco_obj_typ_var && strcmp(var_nm,var_trv.nm) == 0){
-
-      if (strcmp(grp_nm_fll_prn,var_trv.grp_nm_fll_prn) == 0){
-        return &trv_tbl->lst[idx_tbl];
-      }
-
-    }
+    if(var_trv.nco_typ == nco_obj_typ_var && !strcmp(var_nm,var_trv.nm))
+      if(!strcmp(grp_nm_fll_prn,var_trv.grp_nm_fll_prn))
+	return &trv_tbl->lst[idx_tbl];
   }
 
   return NULL;
-
 } /* trv_tbl_nsm_nm() */
 
-
 trv_sct *                              /* O [sct] Table object */
 trv_tbl_nsm_nm_att                     /* [fnc] Return variable object  */
 (const char * const var_nm,            /* I [sng] Variable name (relative) to find */
@@ -1006,15 +986,10 @@ trv_tbl_nsm_nm_att                     /* [fnc] Return variable object  */
 
   for(unsigned idx_tbl=0;idx_tbl<trv_tbl->nbr;idx_tbl++){
     trv_sct var_trv=trv_tbl->lst[idx_tbl];  
-    if(var_trv.nco_typ == nco_obj_typ_var && strcmp(var_nm,var_trv.nm) == 0){
-
-      if (strcmp(grp_nm_fll_prn,var_trv.grp_nm_fll) == 0){
+    if(var_trv.nco_typ == nco_obj_typ_var && !strcmp(var_nm,var_trv.nm))
+      if(!strcmp(grp_nm_fll_prn,var_trv.grp_nm_fll))
         return &trv_tbl->lst[idx_tbl];
-      }
-
-    }
   }
 
   return NULL;
-
 } /* trv_tbl_nsm_nm_att() */
