@@ -1,10 +1,10 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_msa.c,v 1.267 2014/10/02 01:04:32 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_msa.c,v 1.284 2015/02/07 05:42:35 zender Exp $ */
 
 /* Purpose: Multi-slabbing algorithm */
 
-/* Copyright (C) 1995--2014 Charlie Zender
+/* Copyright (C) 1995--2015 Charlie Zender
    This file is part of NCO, the netCDF Operators. NCO is free software.
-   You can redistribute and/or modify NCO under the terms of the 
+   You may redistribute and/or modify NCO under the terms of the 
    GNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file */
 
 #include "nco_msa.h" /* Multi-slabbing algorithm */
@@ -12,7 +12,7 @@
 void *
 nco_msa_rcr_clc /* [fnc] Multi-slab algorithm (recursive routine, returns a single slab pointer */
 (int dpt_crr, /* [nbr] Current depth, we start at 0 */
- int dpt_crr_max, /* [nbr] Maximium depth (i.e., number of dimensions in variable (does not change) */
+ int dpt_crr_max, /* [nbr] Maximum depth (i.e., number of dimensions in variable (does not change) */
  lmt_sct **lmt, /* [sct] Limits of current hyperslabs (these change as we recurse) */
  lmt_msa_sct **lmt_lst, /* [sct] List of limits in each dimension (this remains STATIC as we recurse) */
  var_sct *vara) /* [sct] Information for routine to read variable information and pass information between calls */
@@ -1248,7 +1248,7 @@ nco_cpy_var_val_mlt_lmt_trv         /* [fnc] Copy variable data from input to ou
 
   assert(nco_obj_typ_var == var_trv->nco_typ);
 
-  /* Local copy of object name */ 
+  /* Local copy of object name */
   strcpy(var_nm,var_trv->nm);                
 
   /* Get ID for requested variable from both files */
@@ -1328,8 +1328,8 @@ nco_cpy_var_val_mlt_lmt_trv         /* [fnc] Copy variable data from input to ou
 	  dmn_map_cnt=(long *)nco_malloc(nbr_dim*sizeof(long));
 	  dmn_map_srt=(long *)nco_malloc(nbr_dim*sizeof(long));
 	} /* nbr_dim != 1 */
-	// Following line would be correct were an adequately sized phony dimension declared and ready to accept this many characters
-	// dmn_map_cnt[0]=var_out.sz;
+	/* Following line would be correct were an adequately sized phony dimension declared and ready to accept this many characters */
+	/* dmn_map_cnt[0]=var_out.sz; */
 	dmn_map_cnt[0]=1L;
 	dmn_map_srt[0]=0L;
 	(void)nco_put_vara(out_id,var_out_id,dmn_map_srt,dmn_map_cnt,var_out.val.sngp[0],var_typ_out);
@@ -1345,6 +1345,17 @@ nco_cpy_var_val_mlt_lmt_trv         /* [fnc] Copy variable data from input to ou
 
   /* Write */
   if(flg_write){
+    int ppc; /* [nbr] Precision-preserving compression, i.e., number of total or decimal significant digits */
+    nco_bool flg_nsd; /* [flg] PPC algorithm is NSD */
+    ppc=var_trv->ppc;
+    flg_nsd=var_trv->flg_nsd;
+    if(ppc != NC_MAX_INT){
+      var_out.type=var_typ_out;
+      var_out.id=var_out_id;
+      nco_mss_val_get(out_id,&var_out);
+      if(flg_nsd) (void)nco_var_bitmask(ppc,var_out.type,var_out.sz,var_out.has_mss_val,var_out.mss_val,var_out.val); else (void)nco_var_around(ppc,var_out.type,var_out.sz,var_out.has_mss_val,var_out.mss_val,var_out.val);
+    } /* endif */
+
     if(nbr_dim == 0) (void)nco_put_var1(out_id,var_out_id,0L,var_out.val.vp,var_typ_out); else (void)nco_put_vara(out_id,var_out_id,dmn_map_srt,dmn_map_cnt,var_out.val.vp,var_typ_out);
   } /* !flg_write */
 
@@ -1422,7 +1433,7 @@ nco_cpy_msa_lmt                     /* [fnc] Copy MSA struct from table to local
 
         if(nco_dbg_lvl_get() == nco_dbg_old) (void)fprintf(stdout,"Warning...no limit zone\n "); 
 
-        /* Alloc 1 dummy limit */
+        /* Allocate one dummy limit */
         (*lmt_msa)[dmn_idx_var]->lmt_dmn_nbr=1;
         (*lmt_msa)[dmn_idx_var]->lmt_dmn=(lmt_sct **)nco_malloc(1*sizeof(lmt_sct *));
         (*lmt_msa)[dmn_idx_var]->lmt_dmn[0]=(lmt_sct *)nco_malloc(sizeof(lmt_sct));
@@ -1438,8 +1449,8 @@ nco_cpy_msa_lmt                     /* [fnc] Copy MSA struct from table to local
       } /* Make a limit to read all */
     } /* If there are limits for this variable dimension, get MSA from table */
 
-    /* This dimension does not has a coordinate variable, it must have a unique dimension pointer */
-    else if (var_trv->var_dmn[dmn_idx_var].is_crd_var == False){
+    /* This dimension does not have a coordinate variable, it must have a unique dimension pointer */
+    else if(var_trv->var_dmn[dmn_idx_var].is_crd_var == False){
 
       /* Get number of limits */
       int lmt_dmn_nbr=var_trv->var_dmn[dmn_idx_var].ncd->lmt_msa.lmt_dmn_nbr;
@@ -1513,7 +1524,7 @@ nco_msa_var_get_trv                 /* [fnc] Get variable data from disk taking
   lmt_msa_sct **lmt_msa;
   lmt_sct **lmt;
 
-  nc_type mss_typ_tmp;
+  nc_type mss_typ_tmp=NC_NAT; /* CEWI */
 
   trv_sct *var_trv;
 
@@ -1545,9 +1556,9 @@ nco_msa_var_get_trv                 /* [fnc] Get variable data from disk taking
   (void)nco_cpy_msa_lmt(var_trv,&lmt_msa);
 
   if(nco_dbg_lvl_get() == nco_dbg_old){
-    (void)fprintf(stdout,"%s: DEBUG %s reading <%s>\n",nco_prg_nm_get(),fnc_nm,var_trv->nm_fll);
+    (void)fprintf(stdout,"%s: DEBUG %s reports reading %s\n",nco_prg_nm_get(),fnc_nm,var_trv->nm_fll);
     for(int idx_dmn=0;idx_dmn<var_trv->nbr_dmn;idx_dmn++){
-      (void)fprintf(stdout,"%s: DEBUG %s <%s> elements %ld",nco_prg_nm_get(),fnc_nm,lmt_msa[idx_dmn]->dmn_nm,lmt_msa[idx_dmn]->dmn_cnt);
+      (void)fprintf(stdout,"%s: DEBUG %s reports dimension %s has dmn_cnt = %ld",nco_prg_nm_get(),fnc_nm,lmt_msa[idx_dmn]->dmn_nm,lmt_msa[idx_dmn]->dmn_cnt);
       for(int idx_lmt=0;idx_lmt<lmt_msa[idx_dmn]->lmt_dmn_nbr;idx_lmt++) (void)fprintf(stdout," : %ld (%ld->%ld)",lmt_msa[idx_dmn]->lmt_dmn[idx_lmt]->cnt,lmt_msa[idx_dmn]->lmt_dmn[idx_lmt]->srt,lmt_msa[idx_dmn]->lmt_dmn[idx_lmt]->end);
       (void)fprintf(stdout,"\n");
     } /* end loop over dimensions */
