@@ -1,10 +1,10 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_mss_val.c,v 1.56 2014/06/15 21:06:23 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_mss_val.c,v 1.60 2015/02/05 19:26:55 zender Exp $ */
 
 /* Purpose: Missing value utilities */
 
-/* Copyright (C) 1995--2014 Charlie Zender
+/* Copyright (C) 1995--2015 Charlie Zender
    This file is part of NCO, the netCDF Operators. NCO is free software.
-   You can redistribute and/or modify NCO under the terms of the 
+   You may redistribute and/or modify NCO under the terms of the 
    GNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file */
 
 #include "nco_mss_val.h" /* Missing value utilities */
@@ -37,7 +37,7 @@ nco_mss_val_mk /* [fnc] Return default missing value for type type */
   case NC_UINT64: *mss_val.ui64p=NC_FILL_UINT64; break;
     /* 20140526: Changed to NC_FILL_STRING (available as of netCDF 4.3.1?) */
     /* case NC_STRING: *mss_val.sngp='\0'; break; fxm: NC_FILL_STRING? TODO nco839 */
-  case NC_STRING: *mss_val.sngp=(char *)NC_FILL_STRING; break;
+  case NC_STRING: *mss_val.sngp=(char *)(NC_FILL_STRING); break;
   default: nco_dfl_case_nc_type_err(); break;
   } /* end switch */
 
@@ -284,8 +284,10 @@ nco_mss_val_get /* [fnc] Update number of attributes, missing_value of variable
   size_t att_lng;
 
   /* Refresh netCDF "mss_val" attribute for this variable */
+  if(var->has_mss_val)
+     if(var->mss_val.vp)
+       var->mss_val.vp=(void *)nco_free(var->mss_val.vp);
   var->has_mss_val=False;
-  var->mss_val.vp=nco_free(var->mss_val.vp);
 
   /* Refresh number of attributes for variable */
   (void)nco_inq_varnatts(nc_id,var->id,&var->nbr_att);
