@@ -1,10 +1,10 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_rth_flt.c,v 1.39 2014/06/15 21:06:24 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_rth_flt.c,v 1.42 2015/02/04 04:16:24 zender Exp $ */
 
 /* Purpose: Float-precision arithmetic, MSVC macros */
 
-/* Copyright (C) 1995--2014 Charlie Zender
+/* Copyright (C) 1995--2015 Charlie Zender
    This file is part of NCO, the netCDF Operators. NCO is free software.
-   You can redistribute and/or modify NCO under the terms of the 
+   You may redistribute and/or modify NCO under the terms of the 
    GNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file */
 
 #include "nco_rth_flt.h" /* Float-precision arithmetic, MSVC macros */
@@ -13,14 +13,14 @@
    MSVC does not define lrint(), lrintf(), lrintl(), llrint(), llrintf(), llrintl(): Round to nearest even integer, raise exceptions
    Summary of POSIX, ISO, and MSVC math intrinsics at http://www.johndcook.com/math_h.html */
 #ifdef _MSC_VER
-long long int llrint(double x){return (x >= 0.0) ? floor(x+0.5) : ceil(x-0.5);};
-long long int llrintf(float x){return (x >= 0.0f) ? floorf(x+0.5f) : ceilf(x-0.5f);};
-long int lrint(double x){return (x >= 0.0) ? floor(x+0.5) : ceil(x-0.5);};
-long int lrintf(float x){return (x >= 0.0f) ? floorf(x+0.5f) : ceilf(x-0.5f);};
-long long int llround(double x){return floor(x+0.5);}
-long long int llroundf(float x){return floorf(x+0.5f);}
-long int lround(double x){return floor(x+0.5);}
-long int lroundf(float x){return floorf(x+0.5f);}
+long long int llrint(double x){return (x >= 0.0) ? (long long int)floor(x+0.5) : (long long int)ceil(x-0.5);}; /* casts are CEWI for MSVC */
+long long int llrintf(float x){return (x >= 0.0f) ? (long long int)floorf(x+0.5f) : (long long int)ceilf(x-0.5f);};
+long int lrint(double x){return (x >= 0.0) ? (long int)floor(x+0.5) : (long int)ceil(x-0.5);};
+long int lrintf(float x){return (x >= 0.0f) ? (long int)floorf(x+0.5f) : (long int)ceilf(x-0.5f);};
+long long int llround(double x){return (long long int)floor(x+0.5);}
+long long int llroundf(float x){return (long long int)floorf(x+0.5f);}
+long int lround(double x){return (long int)floor(x+0.5);}
+long int lroundf(float x){return (long int)floorf(x+0.5f);}
 #endif /* !_MSC_VER */ 
 
 /* In ANSI C, <math.h> provides standard math intrinsics in double precision 
@@ -82,7 +82,7 @@ float fabsf(float x){return (float)(fabs((double)x));}
 float floorf(float x){return (float)(floor((double)x));}
 #endif /* !NEED_FLOORF */ 
 #ifdef NEED_GAMMAF
-float gammaf(float x){return (float)(gamma((double)x));}
+float gammaf(float x){return (float)(tgamma((double)x));}
 #endif /* !NEED_GAMMAF */ 
 #ifdef NEED_LOG10F
 float log10f(float x){return (float)(log10((double)x));}
