@@ -1,10 +1,10 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_sng_utl.c,v 1.81 2014/11/25 00:22:02 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_sng_utl.c,v 1.83 2015/02/03 20:25:11 zender Exp $ */
 
 /* Purpose: String utilities */
 
-/* Copyright (C) 1995--2014 Charlie Zender
+/* Copyright (C) 1995--2015 Charlie Zender
    This file is part of NCO, the netCDF Operators. NCO is free software.
-   You can redistribute and/or modify NCO under the terms of the 
+   You may redistribute and/or modify NCO under the terms of the 
    GNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file */
 
 #include "nco_sng_utl.h" /* String utilities */
@@ -68,6 +68,16 @@ strncasecmp /* [fnc] Lexicographical case-insensitive string comparison */
 } /* end strncasecmp() */
 #endif /* !NEED_STRCASECMP */
 
+#ifdef NEED_ISBLANK
+int /* O [flg] Character is a space or horizontal tab */
+isblank /* [fnc] Is character a space or horizontal tab? */
+(const int chr) /* I [enm] Character to check */
+{
+  /* 20150203 Initial version */
+  return chr == ' ' || chr == '\t';
+} /* end isblank() */
+#endif /* !NEED_ISBLANK */
+
 /* 20130827 GNU g++ always provides strcasestr(), MSVC never does */
 #ifndef __GNUG__
 # ifdef NEED_STRCASESTR
