@@ -1,10 +1,10 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_sng_utl.h,v 1.50 2014/10/01 03:50:42 pvicente Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_sng_utl.h,v 1.52 2015/02/03 20:25:11 zender Exp $ */
 
 /* Purpose: String utilities */
 
-/* Copyright (C) 1995--2014 Charlie Zender
+/* Copyright (C) 1995--2015 Charlie Zender
    This file is part of NCO, the netCDF Operators. NCO is free software.
-   You can redistribute and/or modify NCO under the terms of the 
+   You may redistribute and/or modify NCO under the terms of the 
    GNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file */
 
 /* Usage:
@@ -25,6 +25,10 @@
 #endif /* !HAVE_STRINGS_H */
 
 #ifdef _MSC_VER
+/* 20150203 C99 supplies isblank() and isspace() in ctype.h
+   MSVC 2010 has ctype.h and supplies isspace() but lacks isblank() 
+   MSVC 2012+ (apparently) supplies everything expected in ctype.h? */
+# define NEED_ISBLANK
 # define NEED_STRCASESTR
 #endif /* !_MSC_VER */
 
@@ -41,6 +45,12 @@
 extern "C" {
 #endif /* __cplusplus */
 
+#ifdef NEED_ISBLANK
+int /* O [flg] Character is a space or horizontal tab */
+isblank /* [fnc] Is character a space or horizontal tab? */
+(const int chr); /* I [enm] Character to check */
+#endif /* !NEED_ISBLANK */
+
 #ifdef NEED_STRCASECMP
 int /* O [enm] [-1,0,1] sng_1 [<,=,>] sng_2 */
 strcasecmp /* [fnc] Lexicographical case-insensitive string comparison */
