@@ -1,10 +1,10 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_var_avg.c,v 1.80 2014/06/15 21:06:24 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_var_avg.c,v 1.82 2015/02/07 04:39:39 zender Exp $ */
 
 /* Purpose: Average variables */
 
-/* Copyright (C) 1995--2014 Charlie Zender
+/* Copyright (C) 1995--2015 Charlie Zender
    This file is part of NCO, the netCDF Operators. NCO is free software.
-   You can redistribute and/or modify NCO under the terms of the 
+   You may redistribute and/or modify NCO under the terms of the 
    GNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file */
 
 #include "nco_var_avg.h" /* Average variables */
@@ -325,12 +325,15 @@ nco_var_avg /* [fnc] Reduce given variable over specified dimensions */
        nco_var_avg_rdc_*() sets tally array */
     if(var->is_crd_var) nco_op_typ_lcl=nco_op_avg; else nco_op_typ_lcl=nco_op_typ;
     switch(nco_op_typ_lcl){
+    case nco_op_mabs:
     case nco_op_max:
       (void)nco_var_avg_rdc_max(fix->type,var_sz,fix_sz,fix->has_mss_val,fix->mss_val,avg_val,fix->val);
       break;
+    case nco_op_mibs:
     case nco_op_min:
       (void)nco_var_avg_rdc_min(fix->type,var_sz,fix_sz,fix->has_mss_val,fix->mss_val,avg_val,fix->val);
       break;
+    case nco_op_mebs: /* Operations: Previous=none, Current=sum, Next=normalize */
     case nco_op_avg: /* Operations: Previous=none, Current=sum, Next=normalize */
     case nco_op_sqravg: /* Operations: Previous=none, Current=sum, Next=normalize and square */
     case nco_op_avgsqr: /* Operations: Previous=square, Current=sum, Next=normalize */
