@@ -1,10 +1,10 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_var_rth.h,v 1.39 2014/06/15 21:06:24 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_var_rth.h,v 1.47 2015/02/03 17:02:34 zender Exp $ */
 
 /* Purpose: Variable arithmetic */
 
-/* Copyright (C) 1995--2014 Charlie Zender
+/* Copyright (C) 1995--2015 Charlie Zender
    This file is part of NCO, the netCDF Operators. NCO is free software.
-   You can redistribute and/or modify NCO under the terms of the 
+   You may redistribute and/or modify NCO under the terms of the 
    GNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file */
 
 /* Usage:
@@ -14,6 +14,10 @@
 #define NCO_VAR_RTH_H
 
 /* Standard header files */
+/* C++ compilers have math.h but do not define constants like M_LN10, M_LN2 unless _USE_MATH_DEFINES is first defined */
+#ifdef _MSC_VER
+# define _USE_MATH_DEFINES
+#endif /* !_MSC_VER */
 #include <math.h> /* sin cos cos sin 3.14159 */
 #include <stdio.h> /* stderr, FILE, NULL, printf */
 
@@ -32,13 +36,40 @@
 extern "C" {
 #endif /* __cplusplus */
   
+  typedef union{ /* f32_u32_unn */
+    float f32;
+    unsigned int u32;
+  } f32_u32_unn;
+  typedef union{ /* f64_u64_unn */
+    double f64;
+    unsigned long u64;
+  } f64_u64_unn;
+  
   void
   nco_var_abs /* [fnc] Replace op1 values by their absolute values */
   (const nc_type type, /* I [enm] netCDF type of operand */
    const long sz, /* I [nbr] Size (in elements) of operand */
    const int has_mss_val, /* I [flg] Flag for missing values */
    ptr_unn mss_val, /* I [val] Value of missing value */
-   ptr_unn op1); /* I [val] Values of first operand */
+   ptr_unn op1); /* I/O [val] Values of first operand */
+  
+  void
+  nco_var_around /* [fnc] Replace op1 values by their values rounded to decimal precision prc */
+  (const int prc, /* I [nbr] Precision-preserving compression, i.e., number of total or decimal significant digits */
+   const nc_type type, /* I [enm] netCDF type of operand */
+   const long sz, /* I [nbr] Size (in elements) of operand */
+   const int has_mss_val, /* I [flg] Flag for missing values */
+   ptr_unn mss_val, /* I [val] Value of missing value */
+   ptr_unn op1); /* I/O [val] Values of first operand */
+
+  void
+  nco_var_bitmask /* [fnc] Mask-out insignificant bits of significand */
+  (const int nsd, /* I [nbr] Number of significant digits, i.e., arithmetic precision */
+   const nc_type type, /* I [enm] netCDF type of operand */
+   const long sz, /* I [nbr] Size (in elements) of operand */
+   const int has_mss_val, /* I [flg] Flag for missing values */
+   ptr_unn mss_val, /* I [val] Value of missing value */
+   ptr_unn op1); /* I/O [val] Values of first operand */
   
   void
   nco_var_add /* [fnc] Add first operand to second operand */
