@@ -1,13 +1,13 @@
-/* $Header: /cvsroot/nco/nco/src/nco/ncwa.c,v 1.430 2014/11/05 23:39:04 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/ncwa.c,v 1.436 2015/02/09 22:35:36 zender Exp $ */
 
 /* ncwa -- netCDF weighted averager */
 
 /* Purpose: Compute averages of specified hyperslabs of specfied variables
    in a single input netCDF file and output them to a single file. */
 
-/* Copyright (C) 1995--2014 Charlie Zender
+/* Copyright (C) 1995--2015 Charlie Zender
    This file is part of NCO, the netCDF Operators. NCO is free software.
-   You can redistribute and/or modify NCO under the terms of the 
+   You may redistribute and/or modify NCO under the terms of the 
    GNU General Public License (GPL) Version 3.
    As a special exception to the terms of the GPL, you are permitted 
    to link the NCO source code with the HDF, netCDF, OPeNDAP, and UDUnits
@@ -147,12 +147,13 @@ main(int argc,char **argv)
   char *nco_op_typ_sng; /* Operation type */
   char *opt_crr=NULL; /* [sng] String representation of current long-option name */
   char *optarg_lcl=NULL; /* [sng] Local copy of system optarg */
+  char *ppc_arg[NC_MAX_VARS]; /* [sng] PPC arguments */
   char *sng_cnv_rcd=NULL_CEWI; /* [sng] strtol()/strtoul() return code */
   char *wgt_nm=NULL;
   char trv_pth[]="/"; /* [sng] Root path of traversal tree */
 
-  const char * const CVS_Id="$Id: ncwa.c,v 1.430 2014/11/05 23:39:04 zender Exp $"; 
-  const char * const CVS_Revision="$Revision: 1.430 $";
+  const char * const CVS_Id="$Id: ncwa.c,v 1.436 2015/02/09 22:35:36 zender Exp $"; 
+  const char * const CVS_Revision="$Revision: 1.436 $";
   const char * const opt_sht_lst="3467Aa:B:bCcD:d:Fg:G:hIL:l:M:m:nNOo:p:rRT:t:v:Ww:xy:-:";
 
   cnk_sct cnk; /* [sct] Chunking structure */
@@ -208,6 +209,7 @@ main(int argc,char **argv)
   int op_typ_rlt=0; /* Option o */
   int opt;
   int out_id;  
+  int ppc_nbr=0; /* [nbr] Number of PPC arguments */
   int rcd=NC_NOERR; /* [rcd] Return code */
   int thr_idx; /* [idx] Index of current thread */
   int thr_nbr=int_CEWI; /* [nbr] Thread number Option t */
@@ -295,6 +297,9 @@ main(int argc,char **argv)
     {"file_format",required_argument,0,0},
     {"hdr_pad",required_argument,0,0},
     {"header_pad",required_argument,0,0},
+    {"ppc",required_argument,0,0}, /* [nbr] Precision-preserving compression, i.e., number of total or decimal significant digits */
+    {"precision_preserving_compression",required_argument,0,0}, /* [nbr] Precision-preserving compression, i.e., number of total or decimal significant digits */
+    {"quantize",required_argument,0,0}, /* [nbr] Precision-preserving compression, i.e., number of total or decimal significant digits */
     /* Long options with short counterparts */
     {"3",no_argument,0,'3'},
     {"4",no_argument,0,'4'},
@@ -439,6 +444,10 @@ main(int argc,char **argv)
         hdr_pad=strtoul(optarg,&sng_cnv_rcd,NCO_SNG_CNV_BASE10);
         if(*sng_cnv_rcd) nco_sng_cnv_err(optarg,"strtoul",sng_cnv_rcd);
       } /* endif "hdr_pad" */
+      if(!strcmp(opt_crr,"ppc") || !strcmp(opt_crr,"precision_preserving_compression") || !strcmp(opt_crr,"quantize")){
+        ppc_arg[ppc_nbr]=(char *)strdup(optarg);
+        ppc_nbr++;
+      } /* endif "ppc" */
       if(!strcmp(opt_crr,"ram_all") || !strcmp(opt_crr,"create_ram") || !strcmp(opt_crr,"diskless_all")) RAM_CREATE=True; /* [flg] Open (netCDF3) file(s) in RAM */
       if(!strcmp(opt_crr,"ram_all") || !strcmp(opt_crr,"open_ram") || !strcmp(opt_crr,"diskless_all")) RAM_OPEN=True; /* [flg] Create file in RAM */
       if(!strcmp(opt_crr,"vrs") || !strcmp(opt_crr,"version")){
@@ -733,6 +742,9 @@ main(int argc,char **argv)
   /* Make output and input files consanguinous */
   if(fl_out_fmt == NCO_FORMAT_UNDEFINED) fl_out_fmt=fl_in_fmt;
 
+  /* Inititialize, decode, and set PPC information */
+  if(ppc_nbr > 0) nco_ppc_ini(in_id,&dfl_lvl,fl_out_fmt,ppc_arg,ppc_nbr,trv_tbl);
+
   /* Verify output file format supports requested actions */
   (void)nco_fl_fmt_vet(fl_out_fmt,cnk_nbr,dfl_lvl);
 
@@ -916,6 +928,11 @@ main(int argc,char **argv)
       /* Perform non-linear transformations before weighting */
       if(!var_prc[idx]->is_crd_var){
         switch(nco_op_typ){
+        case nco_op_mabs: /* Absolute value variable before weighting */
+        case nco_op_mebs: /* Absolute value variable before weighting */
+        case nco_op_mibs: /* Absolute value variable before weighting */
+	  (void)nco_var_abs(var_prc[idx]->type,var_prc[idx]->sz,var_prc[idx]->has_mss_val,var_prc[idx]->mss_val,var_prc[idx]->val);
+          break;
         case nco_op_avgsqr: /* Square variable before weighting */
         case nco_op_rms: /* Square variable before weighting */
         case nco_op_rmssdn: /* Square variable before weighting */
@@ -971,8 +988,8 @@ main(int argc,char **argv)
           case NC_SHORT: mss_val_dbl=wgt_avg->mss_val.sp[0]; break;
           case NC_USHORT: mss_val_dbl=wgt_avg->mss_val.usp[0]; break;
           case NC_UINT: mss_val_dbl=wgt_avg->mss_val.uip[0]; break;
-          case NC_INT64: mss_val_dbl=wgt_avg->mss_val.i64p[0]; break;
-          case NC_UINT64: mss_val_dbl=wgt_avg->mss_val.ui64p[0]; break;
+          case NC_INT64: mss_val_dbl=(double)wgt_avg->mss_val.i64p[0]; break; /* CEWI for MSVC */
+          case NC_UINT64: mss_val_dbl=(double)wgt_avg->mss_val.ui64p[0]; break; /* CEWI for MSVC */
           case NC_BYTE: mss_val_dbl=wgt_avg->mss_val.bp[0]; break;
           case NC_UBYTE: mss_val_dbl=wgt_avg->mss_val.ubp[0]; break;
           case NC_CHAR: mss_val_dbl=wgt_avg->mss_val.cp[0]; break;
@@ -1026,6 +1043,8 @@ main(int argc,char **argv)
           if( /* Normalize by weighted tally if ....  */
             (nco_op_typ != nco_op_min) && /* ...operation is not min() and... */
             (nco_op_typ != nco_op_max) && /* ...operation is not max() and... */
+            (nco_op_typ != nco_op_mabs) && /* ...operation is not mabs() and... */
+            (nco_op_typ != nco_op_mibs) && /* ...operation is not mabs() and... */
             (nco_op_typ != nco_op_ttl || /* ...operation is not ttl() or... */
 	     var_prc[idx]->is_crd_var) /* ...variable is a coordinate */
             ){ /* Divide numerator by masked, averaged, weights */
@@ -1043,6 +1062,7 @@ main(int argc,char **argv)
           (void)nco_var_nrm(var_prc_out[idx]->type,var_prc_out[idx]->sz,var_prc_out[idx]->has_mss_val,var_prc_out[idx]->mss_val,var_prc_out[idx]->tally,var_prc_out[idx]->val);
         }else{ /* !var_prc[idx]->is_crd_var */
           switch(nco_op_typ){
+          case nco_op_mebs: /* Normalize sum by tally to create mean */
           case nco_op_avg: /* Normalize sum by tally to create mean */
           case nco_op_sqravg: /* Normalize sum by tally to create mean */
           case nco_op_avgsqr: /* Normalize sum of squares by tally to create mean square */
@@ -1055,6 +1075,8 @@ main(int argc,char **argv)
             break;
           case nco_op_min: /* Minimum is already in buffer, do nothing */
           case nco_op_max: /* Maximum is already in buffer, do nothing */	
+          case nco_op_mabs: /* Maximum absolute value is already in buffer, do nothing */	
+          case nco_op_mibs: /* Minimum absolute value is already in buffer, do nothing */	
           case nco_op_ttl: /* Total is already in buffer, do nothing */	
             break;
           default:
@@ -1107,6 +1129,10 @@ main(int argc,char **argv)
       /* Store the output variable ID */
       var_prc_out[idx]->id=var_out_id;
 
+      if(var_trv->ppc != NC_MAX_INT){
+	if(var_trv->flg_nsd) (void)nco_var_bitmask(var_trv->ppc,var_prc_out[idx]->type,var_prc_out[idx]->sz,var_prc_out[idx]->has_mss_val,var_prc_out[idx]->mss_val,var_prc_out[idx]->val); else (void)nco_var_around(var_trv->ppc,var_prc_out[idx]->type,var_prc_out[idx]->sz,var_prc_out[idx]->has_mss_val,var_prc_out[idx]->mss_val,var_prc_out[idx]->val);
+      } /* endif ppc */
+	
 #ifdef _OPENMP
 #pragma omp critical
 #endif /* _OPENMP */
@@ -1191,6 +1217,10 @@ main(int argc,char **argv)
     if(fl_lst_in && fl_lst_abb) fl_lst_in=nco_sng_lst_free(fl_lst_in,1);
     if(fl_lst_abb) fl_lst_abb=nco_sng_lst_free(fl_lst_abb,abb_arg_nbr);
     if(var_lst_in_nbr > 0) var_lst_in=nco_sng_lst_free(var_lst_in,var_lst_in_nbr);
+    /* Free limits */
+    for(idx=0;idx<aux_nbr;idx++) aux_arg[idx]=(char *)nco_free(aux_arg[idx]);
+    for(idx=0;idx<lmt_nbr;idx++) lmt_arg[idx]=(char *)nco_free(lmt_arg[idx]);
+    for(idx=0;idx<ppc_nbr;idx++) ppc_arg[idx]=(char *)nco_free(ppc_arg[idx]);
     /* Free chunking information */
     for(idx=0;idx<cnk_nbr;idx++) cnk_arg[idx]=(char *)nco_free(cnk_arg[idx]);
     if(cnk_nbr > 0) cnk.cnk_dmn=(cnk_dmn_sct **)nco_cnk_lst_free(cnk.cnk_dmn,cnk_nbr);
@@ -1206,7 +1236,7 @@ main(int argc,char **argv)
     var_fix=(var_sct **)nco_free(var_fix);
     var_out=(var_sct **)nco_free(var_out);
     for(idx=0;idx<lmt_nbr;idx++) flg_dne[idx].dim_nm=(char *)nco_free(flg_dne[idx].dim_nm);
-    if (flg_dne) flg_dne=(nco_dmn_dne_t *)nco_free(flg_dne);
+    if(flg_dne) flg_dne=(nco_dmn_dne_t *)nco_free(flg_dne);
     /* Free traversal table */
     trv_tbl_free(trv_tbl); 
   } /* !flg_cln */
